@@ -170,7 +170,7 @@ def get_args_for_generate_template() -> Namespace:
         "template_type",
         metavar="template_type",
         type=str,
-        help="What kind of file template you want to generate.",
+        help="What kind of file template you want to generate. Choices: excel, excel-definition, sprint-schedule or jira-status-mapping.",
         choices=["excel", "excel-definition", "sprint-schedule", "jira-status-mapping"],
     )
 
