@@ -44,7 +44,7 @@ def parse_json_item_to_sort_strategy(json_item: Any) -> SortStrategy:
             if value is not None and type(value) is dict:
                 for name in value:
                     # More config support.
-                    if name.lower() == "ParentLevelIndexRange".lower():
+                    if name.lower() == "ParentScopeIndexRange".lower():
                         strategy_config[
                             name
                         ] = ExcelDefinition.parse_raise_ranking_level_scope_index_expression(
@@ -62,9 +62,11 @@ class ExcelDefinitionColumn(TypedDict):
     type: type | NoneType
     require_sort: bool
     sort_order: bool
+    scope_require_sort: bool
+    scope_sort_order: bool
     inline_weights: int
     raise_ranking: int
-    raise_ranking_level_scope_index: set | NoneType
+    scope_raise_ranking: int
 
 
 def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitionColumn:
@@ -73,9 +75,11 @@ def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitio
     column_type = None
     column_require_sort = False
     column_sort_order = False
+    column_scope_require_sort = False
+    column_scope_sort_order = False
     column_inline_weights = -1
     column_raise_ranking = -1
-    column_raise_ranking_level_scope_index = None
+    column_scope_raise_ranking = -1
 
     for key, value in json_item.items():
         if key.lower() == "index".lower():
@@ -88,14 +92,16 @@ def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitio
             column_require_sort = value
         if key.lower() == "SortOrder".lower():
             column_sort_order = value
+        if key.lower() == "ScopeRequireSort".lower():
+            column_scope_require_sort = value
+        if key.lower() == "ScopeSortOrder".lower():
+            column_scope_sort_order = value
         if key.lower() == "InlineWeights".lower():
             column_inline_weights = value
         if key.lower() == "RaiseRanking".lower():
             column_raise_ranking = value
-        if key.lower() == "RaiseRankingLevelScopeIndex".lower():
-            column_raise_ranking_level_scope_index = (
-                ExcelDefinition.parse_raise_ranking_level_scope_index_expression(value)
-            )
+        if key.lower() == "ScopeRaiseRanking".lower():
+            column_scope_raise_ranking = value
 
     return ExcelDefinitionColumn(
         index=column_index,
@@ -103,9 +109,11 @@ def parse_json_item_to_excel_definition_column(json_item: Any) -> ExcelDefinitio
         type=column_type,
         require_sort=column_require_sort,
         sort_order=column_sort_order,
+        scope_require_sort=column_scope_require_sort,
+        scope_sort_order=column_scope_sort_order,
         inline_weights=column_inline_weights,
         raise_ranking=column_raise_ranking,
-        raise_ranking_level_scope_index=column_raise_ranking_level_scope_index,
+        scope_raise_ranking=column_scope_raise_ranking,
     )
 
 
@@ -212,8 +220,8 @@ class ExcelDefinition:
                 strategy_priorities.append(strategy["priority"])
 
             if (
-                "ParentLevelIndexRange" in strategy["config"]
-                and type(strategy["config"]["ParentLevelIndexRange"]) is not set
+                "ParentScopeIndexRange" in strategy["config"]
+                and type(strategy["config"]["ParentScopeIndexRange"]) is not set
             ):
                 invalid_definitions.append(
                     f"The format of the Parent Level Index Range is invalid. Strategy: {strategy['name']}. Supported format strings like: 1-20 or 20,30 or empty string."
@@ -233,11 +241,11 @@ class ExcelDefinition:
             column_type: type | None = column["type"]
             column_require_sort: bool = column["require_sort"]
             column_sort_order: bool = column["sort_order"]
+            column_scope_require_sort: bool = column["scope_require_sort"]
+            column_scope_sort_order: bool = column["scope_sort_order"]
             column_inline_weights: int = column["inline_weights"]
             column_raise_ranking: int = column["raise_ranking"]
-            column_raise_ranking_level_scope_index: set | None = column[
-                "raise_ranking_level_scope_index"
-            ]
+            column_scope_raise_ranking: int = column["scope_raise_ranking"]
 
             # Check Name cannot be empty
             if type(column_name) is not str or len(column_name) == 0:
@@ -280,6 +288,17 @@ class ExcelDefinition:
                     f"Sort Order can only be True(Descending)/False(Ascending). Column: {column_name}"
                 )
 
+            # Check Sort
+            if type(column_scope_require_sort) is not bool:
+                invalid_definitions.append(
+                    f"Scope Require Sort can only be True/False. Column: {column_name}"
+                )
+
+            if type(column_scope_sort_order) is not bool:
+                invalid_definitions.append(
+                    f"Scope Sort Order can only be True(Descending)/False(Ascending). Column: {column_name}"
+                )
+
             # Check InlineWeights
             # TODO: Currently only support different line weights.
             if type(column_inline_weights) is not int:
@@ -303,51 +322,21 @@ class ExcelDefinition:
                 )
             else:
                 # Check Support RaiseRanking or not
-                if (
-                    column_type not in (bool, Milestone, str, Priority)
-                    and column_raise_ranking > 0
-                ):
+                if column_type not in (bool,) and column_raise_ranking > 0:
                     invalid_definitions.append(
                         f"Column do not support Raise Ranking feature. Column: {column_name}"
                     )
 
-            if type(column_raise_ranking_level_scope_index) is not set:
+            if type(column_scope_raise_ranking) is not int:
                 invalid_definitions.append(
-                    f"The format of the Raise Ranking Level Scope is invalid. Column: {column_name}. Supported format strings like: 1-20 or 20,30 or empty string."
+                    f"Scope Raise Ranking can only be number. Column: {column_name}"
                 )
-
-        # Make sure NO exist same ranking inside the same level scope .
-        if len(invalid_definitions) == 0:
-            ranking_definition: dict[int, list[tuple[str, set]]] = {}
-            for column in self.get_columns():
-                column_name: str | None = column["name"]
-                column_raise_ranking: int = column["raise_ranking"]
-                column_raise_ranking_level_scope_index: set | None = column[
-                    "raise_ranking_level_scope_index"
-                ]
-                if (
-                    column_raise_ranking == 0  # Not anticipate the sorting.
-                    # Below two conditions will not happened
-                    or column_name is None
-                    or column_raise_ranking_level_scope_index is None
-                ):
-                    continue
-                if column_raise_ranking in ranking_definition:
-                    has_duplicate: bool = False
-                    for name, indexes in ranking_definition[column_raise_ranking]:
-                        if column_raise_ranking_level_scope_index == indexes:
-                            invalid_definitions.append(
-                                f"Same raise ranking value cannot be existed in the same level scope. Column: {name}, Scope: {column_raise_ranking_level_scope_index}."
-                            )
-                            has_duplicate = True
-                    if not has_duplicate:
-                        ranking_definition[column_raise_ranking].append(
-                            (column_name, column_raise_ranking_level_scope_index)
-                        )
-                else:
-                    ranking_definition[column_raise_ranking] = [
-                        (column_name, column_raise_ranking_level_scope_index)
-                    ]
+            else:
+                # Check Support RaiseRanking or not
+                if column_type not in (bool,) and column_scope_raise_ranking > 0:
+                    invalid_definitions.append(
+                        f"Column do not support Scope Raise Ranking feature. Column: {column_name}"
+                    )
 
         if len(invalid_definitions) == 0:
             self.columns.sort(key=lambda c: c["index"], reverse=False)
