@@ -13,6 +13,7 @@ from urllib3 import disable_warnings
 
 from .excel_definition import *
 from .jira_client import *
+from .jira_status import *
 from .milestone import *
 from .priority import *
 from .sprint_schedule import *
@@ -303,13 +304,7 @@ def process_excel_file(
         )
         return
 
-    # TODO: Move to json file.
-    noneed_sort_statuses = [
-        "SPRINT COMPLETE",
-        "PENDING RELEASE",
-        "PRODUCTION TESTING",
-        "CLOSED",
-    ]
+    noneed_sort_statuses = get_no_need_sort_statuses()
 
     stories_has_story_id = []
     for story in stories:
@@ -360,7 +355,9 @@ def process_excel_file(
         if sort_strategy["name"].lower() in "InlineWeights".lower():
             stories_need_sort = sorted(stories_need_sort, reverse=True)
         elif sort_strategy["name"].lower() in "SortOrder".lower():
-            sort_stories_by_property_and_order(stories_need_sort, excel_definition)
+            sort_stories_by_property_and_order(
+                stories_need_sort, excel_definition, sort_strategy["config"]
+            )
         elif sort_strategy["name"].lower() in "RaiseRanking".lower():
             stories_need_sort = sort_stories_by_raise_ranking(
                 stories_need_sort, excel_definition, sort_strategy["config"]
