@@ -275,16 +275,32 @@ class StoryFactory(object):
 
 
 def sort_stories_by_property_and_order(
-    stories: "list[Story]", excel_definition: ExcelDefinition
+    stories: "list[Story]", excel_definition: ExcelDefinition, config: dict
 ):
-    sort_rules: list[tuple] = []
+    sort_rules: list[tuple[str, bool]] = []
     excel_definition_columns = excel_definition.get_columns()
 
-    for column in excel_definition_columns:
-        if column["require_sort"] is True:
-            sort_rules.append((column["name"], column["sort_order"]))
+    if "ParentScopeIndexRange" in config:
+        column_definitions: dict[int, ExcelDefinitionColumn] = {
+            c["index"]: c for c in excel_definition_columns
+        }
 
-    _internal_sort_stories_by_property_and_order(stories, sort_rules)
+        for column in excel_definition_columns:
+            if column["scope_require_sort"] is True and column["name"] is not None:
+                sort_rules.append((column["name"], column["scope_sort_order"]))
+
+        _internal_sort_stories_by_property_and_order_considering_parent_range(
+            stories,
+            column_definitions,
+            sort_rules,
+            config["ParentScopeIndexRange"],
+        )
+    else:
+        for column in excel_definition_columns:
+            if column["require_sort"] is True and column["name"] is not None:
+                sort_rules.append((column["name"], column["sort_order"]))
+
+        _internal_sort_stories_by_property_and_order(stories, sort_rules)
 
 
 def _internal_sort_stories_by_property_and_order(
@@ -299,7 +315,7 @@ def sort_stories_by_raise_ranking(
 ) -> "list[Story]":
     if stories is None:
         return []
-    sort_rules: list[tuple[str, int, Optional[set]]] = []
+    sort_rules: list[tuple[str, int, int]] = []
     excel_definition_columns = excel_definition.get_columns()
 
     for column in excel_definition_columns:
@@ -308,37 +324,39 @@ def sort_stories_by_raise_ranking(
                 (
                     column["name"],
                     column["raise_ranking"],
-                    column["raise_ranking_level_scope_index"],
+                    column["scope_raise_ranking"],
                 )
             )
 
     if len(sort_rules) == 0:
         return stories
 
-    sort_rules.sort(key=lambda x: x[1], reverse=True)  # sort by raise_ranking
-
     result = []
 
     # New raise ranking mode.
-    if "ParentLevelIndexRange" in config:
+    if "ParentScopeIndexRange" in config:
+        sort_rules.sort(key=lambda x: x[2], reverse=True)  # sort by scope_raise_ranking
+
         column_definitions: dict[int, ExcelDefinitionColumn] = {
             c["index"]: c for c in excel_definition_columns
         }
 
-        result = _raise_story_ranking_by_property_v2(
+        result = _internal_raise_story_ranking_by_property_considering_parent_level(
             stories,
             column_definitions,
             sort_rules,
-            config["ParentLevelIndexRange"],
+            config["ParentScopeIndexRange"],
         )
     else:
+        sort_rules.sort(key=lambda x: x[1], reverse=True)  # sort by raise_ranking
+
         for property_name, _, _ in sort_rules:
-            result = _raise_story_ranking_by_property(stories, property_name)
+            result = _internal_raise_story_ranking_by_property(stories, property_name)
 
     return result
 
 
-def _raise_story_ranking_by_property(
+def _internal_raise_story_ranking_by_property(
     stories: "list[Story]", property_name: str
 ) -> "list[Story]":
     if stories is None or len(stories) == 0:
@@ -346,7 +364,13 @@ def _raise_story_ranking_by_property(
     # Use first story as example
     if not hasattr(stories[0], property_name):
         return stories
-    # Only bool indicator for now
+    return _raise_story_ranking_by_property(stories, property_name)
+
+
+# Only bool indicator for now
+def _raise_story_ranking_by_property(
+    stories: "list[Story]", property_name: str
+) -> "list[Story]":
     if type(getattr(stories[0], property_name)) is not bool:
         return stories
     result: list[Story] = [stories[0]] * len(stories)
@@ -362,10 +386,10 @@ def _raise_story_ranking_by_property(
     return result
 
 
-def _raise_story_ranking_by_property_v2(
+def _internal_sort_stories_by_property_and_order_considering_parent_range(
     stories: "list[Story]",
     story_columns: "dict[int, ExcelDefinitionColumn]",
-    sort_rules: "list[tuple[str, int, Optional[set]]]",
+    sort_rules: "list[tuple[str, bool]]",
     parent_level_index_range: "set[int]",
 ) -> "list[Story]":
     begin_index = 0
@@ -387,11 +411,47 @@ def _raise_story_ranking_by_property_v2(
                 break
         # Same parent level process
         stories[begin_index : end_index + 1]
-        for column_name, _, _ in reversed(sort_rules):
+        for column_name, sort_order in reversed(sort_rules):
             stories[begin_index : end_index + 1] = sorted(
                 stories[begin_index : end_index + 1],
                 key=attrgetter(column_name),
-                reverse=True,
+                reverse=sort_order,
+            )
+
+        begin_index = end_index + 1
+        end_index = begin_index
+
+    return stories
+
+
+def _internal_raise_story_ranking_by_property_considering_parent_level(
+    stories: "list[Story]",
+    story_columns: "dict[int, ExcelDefinitionColumn]",
+    sort_rules: "list[tuple[str, int, int]]",
+    parent_level_index_range: "set[int]",
+) -> "list[Story]":
+    begin_index = 0
+    end_index = 0
+    while end_index <= len(stories) - 1:
+        for i in range(begin_index, len(stories) - 1):
+            all_parent_column_matched = True
+            for column_index in parent_level_index_range:
+                if (
+                    stories[i][story_columns[column_index]["name"]]
+                    != stories[i + 1][story_columns[column_index]["name"]]
+                ):
+                    all_parent_column_matched = False
+                    break
+            if all_parent_column_matched:
+                continue
+            else:
+                end_index = i
+                break
+
+        # Same parent level process
+        for column_name, _, _ in reversed(sort_rules):
+            stories[begin_index : end_index + 1] = _raise_story_ranking_by_property(
+                stories[begin_index : end_index + 1], column_name
             )
 
         begin_index = end_index + 1
